# OpenSearch::Client is an unofficial client for OpenSearch. 
# It is derived from Search::Elasticsearch version 7.714
# License details from the original work are contained in the
# NOTICE file distributed with this work.
#
#-----------------------------------------------------------------------
# OpenSearch::Client
#-----------------------------------------------------------------------
# Copyright 2026 Mark Dootson
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

use Test::More;
use Test::Deep;
use Test::Exception;
use strict;
use warnings;
use lib 't/lib';

my $es;
$ENV{OS_VERSION} = '3_0';
local $ENV{OS_CXN_POOL};

$ENV{OS_CXN_POOL} = 'Static';
$es = do "os_sync.pl" or die( $@ || $! );
is $es->info->{tagline}, "The OpenSearch Project: https://opensearch.org/", 'CxnPool::Static';

$ENV{OS_CXN_POOL} = 'Static::NoPing';
$es = do "os_sync.pl" or die( $@ || $! );
is $es->info->{tagline}, "The OpenSearch Project: https://opensearch.org/", 'CxnPool::Static::NoPing';

unless ($ENV{OS} =~ /https/) {
    $ENV{OS_CXN_POOL} = 'Sniff';
    $es = do "os_sync.pl" or die( $@ || $! );
    is $es->info->{tagline}, "The OpenSearch Project: https://opensearch.org/", 'CxnPool::Sniff';

    my ($node) = values %{ $es->transport->cxn_pool->next_cxn->sniff };
    ok $node->{http}{max_content_length_in_bytes}, 'Sniffs max_content length';
}
done_testing;
