# OpenSearch::Client is an unofficial client for OpenSearch. 
# It is derived from Search::Elasticsearch version 7.714
# License details from the original work are contained in the
# NOTICE file distributed with this work.
#
#-----------------------------------------------------------------------
# OpenSearch::Client
#-----------------------------------------------------------------------
# Copyright 2026 Mark Dootson
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package OpenSearch::Client::Core::3_0::Direct::SnapshotManagement;
$OpenSearch::Client::Core::3_0::Direct::SnapshotManagement::VERSION = '3.007009';
use Moo;
with 'OpenSearch::Client::Core::3_0::Role::API';
with 'OpenSearch::Client::Role::Client::Direct';
use namespace::clean;

our %_api_method_supported_version_stash;

sub method_supported_in_version {
    my( $self, @args ) = @_;
    my %params = ( ref($args[0]) ) ? %{ $args[0] } : @args;
    my $version = $params{version};
    my $method  = $params{method};
    return 0 unless($method && $version);
    return 0 unless(exists($_api_method_supported_version_stash{$method}));
    my $supported_version = $_api_method_supported_version_stash{$method};
    my $checkversion = version->declare('v' . $version)->numify;
    return ( $checkversion < $supported_version ) ? 0 : 1;
}

__PACKAGE__->_install_api('sm');

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

B<OpenSearch::Client::Core::3_0::Direct::SnapshotManagement>

=head1 VERSION

version 3.007009

=head1 SYNOPSIS

  use OpenSearch::Client;
  
  my $client = OpenSearch::Client->new( ... );
  
  my $response = $client->sm-><methodname>(
    valone => $value1,
    valtwo => $value2
  );

=head1 DESCRIPTION

B<Snapshot Management API>


Use the Snapshot Management (SM) API to automate taking snapshots.

L<See OpenSearch documentation for sm.|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>

=head1 METHODS
    
=head2 create_policy

Creates a snapshot management policy.

I<Paths served by this method:>

=over

=item
C<POST /_plugins/_sm/policies/{policy_name}>

=back

I<Method added in OpenSearch version 2.1>


    $resp = $client->sm->create_policy(
        
        'body'         =>  $body,      # optional
        
         # path parameters
        
        'policy_name'  =>  $policy_name,  # required
        
         # Common API query string parameters
        
        'error_trace'  =>  $qval1,     # boolean
        'filter_path'  =>  $qval2,     # list
        'human'        =>  $qval3,     # boolean
        'pretty'       =>  $qval4,     # boolean
        'source'       =>  $qval5,     # string
    );

L<OpenSearch documentation for sm-E<gt>create_policy|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>
    
=head2 delete_policy

Deletes a snapshot management policy.

I<Paths served by this method:>

=over

=item
C<DELETE /_plugins/_sm/policies/{policy_name}>

=back

I<Method added in OpenSearch version 2.1>


    $resp = $client->sm->delete_policy(
        
         # path parameters
        
        'policy_name'  =>  $policy_name,  # required
        
         # Common API query string parameters
        
        'error_trace'  =>  $qval1,     # boolean
        'filter_path'  =>  $qval2,     # list
        'human'        =>  $qval3,     # boolean
        'pretty'       =>  $qval4,     # boolean
        'source'       =>  $qval5,     # string
    );

L<OpenSearch documentation for sm-E<gt>delete_policy|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>
    
=head2 explain_policy

Explains the state of the snapshot management policy.

I<Paths served by this method:>

=over

=item
C<GET /_plugins/_sm/policies/{policy_name}/_explain>

=back

I<Method added in OpenSearch version 2.1>


    $resp = $client->sm->explain_policy(
        
         # path parameters
        
        'policy_name'  =>  $policy_name,  # required
        
         # Common API query string parameters
        
        'error_trace'  =>  $qval1,     # boolean
        'filter_path'  =>  $qval2,     # list
        'human'        =>  $qval3,     # boolean
        'pretty'       =>  $qval4,     # boolean
        'source'       =>  $qval5,     # string
    );

L<OpenSearch documentation for sm-E<gt>explain_policy|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>
    
=head2 get_policies

Retrieves all snapshot management policies with optional pagination and filtering.

I<Paths served by this method:>

=over

=item
C<GET /_plugins/_sm/policies>

=back

I<Method added in OpenSearch version 2.1>


    $resp = $client->sm->get_policies(
        
         # Endpoint specific query string parameters
        
        'from'         =>  $qval1,     # number
        'queryString'  =>  $qval2,     # string
        'size'         =>  $qval3,     # number
        'sortField'    =>  $qval4,     # string
        'sortOrder'    =>  $qval5,     # string
        
         # Common API query string parameters
        
        'error_trace'  =>  $qval6,     # boolean
        'filter_path'  =>  $qval7,     # list
        'human'        =>  $qval8,     # boolean
        'pretty'       =>  $qval9,     # boolean
        'source'       =>  $qval10,    # string
    );

L<OpenSearch documentation for sm-E<gt>get_policies|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>
    
=head2 get_policy

Retrieves a specific snapshot management policy by name.

I<Paths served by this method:>

=over

=item
C<GET /_plugins/_sm/policies/{policy_name}>

=back

I<Method added in OpenSearch version 2.1>


    $resp = $client->sm->get_policy(
        
         # path parameters
        
        'policy_name'  =>  $policy_name,  # required
        
         # Common API query string parameters
        
        'error_trace'  =>  $qval1,     # boolean
        'filter_path'  =>  $qval2,     # list
        'human'        =>  $qval3,     # boolean
        'pretty'       =>  $qval4,     # boolean
        'source'       =>  $qval5,     # string
    );

L<OpenSearch documentation for sm-E<gt>get_policy|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>
    
=head2 start_policy

Starts a snapshot management policy.

I<Paths served by this method:>

=over

=item
C<POST /_plugins/_sm/policies/{policy_name}/_start>

=back

I<Method added in OpenSearch version 2.1>


    $resp = $client->sm->start_policy(
        
         # path parameters
        
        'policy_name'  =>  $policy_name,  # required
        
         # Common API query string parameters
        
        'error_trace'  =>  $qval1,     # boolean
        'filter_path'  =>  $qval2,     # list
        'human'        =>  $qval3,     # boolean
        'pretty'       =>  $qval4,     # boolean
        'source'       =>  $qval5,     # string
    );

L<OpenSearch documentation for sm-E<gt>start_policy|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>
    
=head2 stop_policy

Stops a snapshot management policy.

I<Paths served by this method:>

=over

=item
C<POST /_plugins/_sm/policies/{policy_name}/_stop>

=back

I<Method added in OpenSearch version 2.1>


    $resp = $client->sm->stop_policy(
        
         # path parameters
        
        'policy_name'  =>  $policy_name,  # required
        
         # Common API query string parameters
        
        'error_trace'  =>  $qval1,     # boolean
        'filter_path'  =>  $qval2,     # list
        'human'        =>  $qval3,     # boolean
        'pretty'       =>  $qval4,     # boolean
        'source'       =>  $qval5,     # string
    );

L<OpenSearch documentation for sm-E<gt>stop_policy|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>
    
=head2 update_policy

Updates an existing snapshot management policy. Requires `if_seq_no` and `if_primary_term`.

I<Paths served by this method:>

=over

=item
C<PUT /_plugins/_sm/policies/{policy_name}>

=back

I<Method added in OpenSearch version 2.1>


    $resp = $client->sm->update_policy(
        
        'body'             =>  $body,      # optional
        
         # path parameters
        
        'policy_name'      =>  $policy_name,  # required
        
         # Endpoint specific query string parameters
        
        'if_primary_term'  =>  $qval1,     # number
        'if_seq_no'        =>  $qval2,     # number
        
         # Common API query string parameters
        
        'error_trace'      =>  $qval3,     # boolean
        'filter_path'      =>  $qval4,     # list
        'human'            =>  $qval5,     # boolean
        'pretty'           =>  $qval6,     # boolean
        'source'           =>  $qval7,     # string
    );

L<OpenSearch documentation for sm-E<gt>update_policy|https://docs.opensearch.org/latest/tuning-your-cluster/availability-and-recovery/snapshots/sm-api/>

=head2 method_supported_in_version

Return whether a method in this module namespace is supported for an OpenSearch server version

    my $boolean = $os->sm->method_supported_in_version(
        method  => 'create_policy',
        version => '2.4.0'
    );

Both C<method> and C<version> are required.

See also L<global_method_supported_in_version|OpenSearch::Client::Core::3_0::Direct#global_method_supported_in_version>

=head1 MANUAL

Documentation index L<OpenSearch::Client::Manual>

=head1 HISTORY

This distribution is derived from L<Search::Elasticsearch> version 7.714.
All subsequent changes are unique to this distribution.

=head1 AUTHOR

Mark Dootson E<lt>mdootson@cpan.orgE<gt> ( current maintainer )

=head1 CREDITS

L<OpenSearch::Client> is based on L<Search::Elasticsearch> version 7.714
by Enrico Zimuel E<lt>enrico.zimuel@elastic.coE<gt>.

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2026 by Mark Dootson ( this distribution )

Copyright (C) 2021 by Elasticsearch BV ( original distribution ) 

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004


=cut

